@@ -1,16 +1,14 @@
-use 5.008;
-
 use MooseX::Declare;
 
 class Bot::BasicBot::Pluggable::Module::Gitbot
     extends Bot::BasicBot::Pluggable::Module
 {
-    our $VERSION = '0.01.06';
-
     use File::Fu   qw();
     use File::Spec qw();
     use Git        qw();
 
+    use Data::Dumper::Concise::Sugar;
+
     use File::Basename  qw( basename  );
     use Text::Pluralize qw( pluralize );
 
@@ -56,7 +54,13 @@ class Bot::BasicBot::Pluggable::Module::Gitbot
             } ? 1 : 0;
         });
 
-        return unless $repo;
+        unless ($repo) {
+            $self->reply(
+                $message,
+                "Huh?  I have no clue what you're talking about...",
+            );
+            return;
+        }
 
         my $type = eval {
             $repo->command_oneline(
@@ -153,6 +157,14 @@ class Bot::BasicBot::Pluggable::Module::Gitbot
 
 Bot::BasicBot::Pluggable::Module::Gitbot - A Bot::BasicBot::Pluggable Module to give out Gitweb links for commits.
 
+=head1 VERSION
+
+Version 0.01
+
+=cut
+
+our $VERSION = '0.01';
+
 =head1 SYNOPSIS
 
     use Bot::BasicBot::Pluggable;
